/***********************************************************
 * 7366_test.c : C-file which runs tests that use the
 *				 LS7166 parallel-interface encoder chip.
 *	
 * Creation date: 20-APR-2010
 * Last modified: 20-APR-2010
 *
 * Thomas Peterson
 * LIMS
 ********************************************************************/

#include "HardwareProfile.h"
#include "7166.h"
#include <plib.h>


#pragma config FPBDIV = DIV_1            //Sets PBCLK to SYSCLK
#define FPB 80000000

void setup_rs232(int pbClk) {
	#define config1 	UART_EN | UART_IDLE_CON | UART_RX_TX | UART_DIS_WAKE | UART_DIS_LOOPBACK | UART_DIS_ABAUD | UART_NO_PAR_8BIT | UART_1STOPBIT | UART_IRDA_DIS | UART_DIS_BCLK_CTS_RTS| UART_NORMAL_RX | UART_BRGH_SIXTEEN
	#define config2		UART_TX_PIN_LOW | UART_RX_ENABLE | UART_TX_ENABLE | UART_INT_TX | UART_INT_RX_CHAR | UART_ADR_DETECT_DIS | UART_RX_OVERRUN_CLEAR
	// Open UART2 with config1 and config2
	OpenUART2( config1, config2, pbClk/16/9600-1);	// calculate actual BAUD generate value.
	putsUART2("UART init done\r\n");
}
void Delayms( unsigned t)
// This uses Timer 1, can be changed to another timer. Assumes FPB = SYS_FREQ
{
    OpenTimer1(T1_ON | T1_PS_1_256, 0xFFFF);
    while (t--)
    {  // t x 1ms loop
        WriteTimer1(0);
        while (ReadTimer1() < FPB/256/1000);
	}
	CloseTimer1();
} // Delayms


/* Main Function */
int main(void)
{
	// Configure the proper PB frequency and the number of wait states
	int pbClk = SYSTEMConfigPerformance(SYS_FREQ);
	
	// Set all analog pins to be digital I/O
	AD1PCFG = 0xFFFF;
	
	//Init I/O
	//Set comm bits as outputs
	TRISD &= 0xFFE1; 	//D4-D1 outputs (0)
	TRISC &= 0xFFE1; 	//C4-C1 outputs (0)
	//TRISB (data bus) handled by comm fcns
	//Set outputs high (inactive)
	NWR = 1;
	NCS = 1;
	C_ND = 1;
	NRD = 1;

	
	//UART setup
	setup_rs232(pbClk);

	//7166 setup
	init_7166();
	
	//Read peroidically and send encoder value
	unsigned int readval;
	char string[40];
	while(1) {
		Delayms(250);
		readval = read_reg(OL);
		sprintf(string,"Read from OL: %x , OSR \r\n", readval );
		putsUART2(string);
	}	
}
